ScopeToolExt

Trait ScopeToolExt 

pub trait ScopeToolExt: Tool + Sized {
    // Provided method
    fn with_scope_guard(
        self,
        resolver: impl ScopeResolver + 'static,
    ) -> ScopedTool<Self> { ... }
}
Extension trait for easily wrapping tools with scope enforcement.

Provided Methods

fn with_scope_guard( self, resolver: impl ScopeResolver + 'static, ) -> ScopedTool<Self>

Wrap this tool with scope enforcement using the given resolver.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<T: Tool> ScopeToolExt for T